@@ -29,6 +29,15 @@ class SimpleQueue:
         except Empty:
             return None, None
 
+    def get_batch(self, block=False, timeout=None, num=1000):
+        data_list = []
+        try:
+            while len(data_list) < num:
+                data_list.append(self._queue.get(block=block, timeout=timeout))
+        except Empty:
+            pass
+        return data_list
+
     def ack(self, qid):
         if not self._ack:
             return True
