@@ -4,6 +4,7 @@ from .brokers.simple_topic_agent import SimpleTopicAgent
 from .brokers.unique_key_topic_agent import UniqueKeyTopicAgent
 from flask import Flask
 from flask import jsonify
+from flask import redirect
 from .common.protocol import DEFAULT_SIMPLE_AGENT_NAME
 from .common.protocol import DEFAULT_UNIQUE_KEY_AGENT_NAME
 from loguru import logger
@@ -36,6 +37,12 @@ def index():
     }
     return jsonify(resp)
 
+@app.route('/clear')
+def clear():
+    unique_key_agent.clear()
+    simple_agent.clear()
+    return redirect('/')
+
 
 class QueueManager(BaseManager):
     pass
